==> cxf-testutils-2.0.6.14-fuse-sources.jar: org/apache/type_test/xml/TestRecOuterType.java <==

package org.apache.type_test.xml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types3.RecOuterType;


/**
 * <p>Java class for testRecOuterType element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="testRecOuterType">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="x" type="{http://apache.org/type_test/types3}RecOuterType"/>
 *           &lt;element name="y" type="{http://apache.org/type_test/types3}RecOuterType"/>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testRecOuterType")
public class TestRecOuterType {

    @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
    protected RecOuterType x;
    @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
    protected RecOuterType y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link RecOuterType }
     *     
     */
    public RecOuterType getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link RecOuterType }
     *     
     */
    public void setX(RecOuterType value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link RecOuterType }
     *     
     */
    public RecOuterType getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link RecOuterType }
     *     
     */
    public void setY(RecOuterType value) {
        this.y = value;
    }

}

==> cxf-testutils-2.1.3.13-fuse-sources.jar: org/apache/type_test/xml/TestRecOuterType.java <==

package org.apache.type_test.xml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types3.RecOuterType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="x" type="{http://apache.org/type_test/types3}RecOuterType"/>
 *         &lt;element name="y" type="{http://apache.org/type_test/types3}RecOuterType"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testRecOuterType")
public class TestRecOuterType {

    @XmlElement(required = true)
    protected RecOuterType x;
    @XmlElement(required = true)
    protected RecOuterType y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link RecOuterType }
     *     
     */
    public RecOuterType getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link RecOuterType }
     *     
     */
    public void setX(RecOuterType value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link RecOuterType }
     *     
     */
    public RecOuterType getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link RecOuterType }
     *     
     */
    public void setY(RecOuterType value) {
        this.y = value;
    }

}
